/* **********************************************************************
    Copyright 2003 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.sss.util.servlets.io;

import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletResponseWrapper;
import javax.servlet.ServletOutputStream;
import org.apache.log4j.Logger;

/** This class provides a useful form of the wrapped response.
 */
public class WrappedResponse extends HttpServletResponseWrapper {
  protected boolean debug = false;

  private transient Logger log;

  public WrappedResponse(HttpServletResponse response,
                         boolean debug) {
    this(response, null, debug);
  }

  public WrappedResponse(HttpServletResponse response,
                         Logger log,
                         boolean debug) {
    super(response);
    this.log = log;
    this.debug = debug;
  }

  public void sendError(int sc) throws IOException {
    super.sendError(sc);
    if (debug) {
      getLogger().debug("sendError(" + sc + ")");
    }
  }

  public void setStatus(int sc) {
    super.setStatus(sc);
    if (debug) {
      getLogger().debug("setStatus(" + sc + ")");
    }
  }

  public void addHeader(String name, String value) {
    super.addHeader(name, value);
    if (debug) {
      getLogger().debug("addHeader(\"" + name + "\", \"" + value + "\")");
    }
  }

  public void setHeader(String name, String value) {
    super.setHeader(name, value);
    if (debug) {
      getLogger().debug("setHeader(\"" + name + "\", \"" + value + "\")");
    }
  }

  public int getBufferSize() {
    return 0;
  }

  public void flushBuffer() {
    if (debug) {
      getLogger().debug("flushBuffer called");
    }
  }

  /** We should probably have a setCharacterEncoding method as well and
   * subclasses can use the current character encoding to convert to String
   */
  public void setContentType(String type) {
    getResponse().setContentType(type);
    if (debug) {
      getLogger().debug("setContentType(\"" + type + "\")");
    }
  }

  public void close() {
  }

  /** Get a logger for messages
   */
  protected Logger getLogger() {
    if (log == null) {
      log = Logger.getLogger(this.getClass());
    }

    return log;
  }
}

