/* **********************************************************************
    Copyright 2003 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.uwcal.admin.location;

import edu.rpi.cct.uwcal.admin.PEAbstractAction;
import edu.rpi.cct.uwcal.admin.PEActionForm;
import edu.rpi.cct.uwcal.calsvci.CalSvcI;
import edu.rpi.cct.uwcal.webcommon.UWCalSession;

import edu.washington.cac.calfacade.shared.CalFacadeDefs;
import edu.washington.cac.calfacade.shared.LocationVO;

import javax.servlet.http.HttpServletRequest;

/** This action updates a location.
 *
 * <p>Forwards to:<ul>
 *      <li>"noAccess"     user not authorised.</li>
 *      <li>"notFound"     no such event.</li>
 *      <li>"continue"     continue on to update page.</li>
 * </ul>
 *
 * @author Mike Douglass   douglm@rpi.edu
 */
public class PEUpdateLocationAction extends PEAbstractAction {
  /** This is the routine which does the work.
   *
   * @param request   Needed to locate session
   * @param sess      UWCalSession calendar session object
   * @param form      Action form
   * @return String   forward name
   */
  public String doAction(HttpServletRequest request,
                         UWCalSession sess,
                         PEActionForm form) throws Throwable {
    /** Check access
     */
    if (!form.getAuthorisedUser()) {
      return "noAccess";
    }

    String reqpar = request.getParameter("delete");

    if (reqpar != null) {
      return "delete";
    }

    CalSvcI svci = form.getCalSvcI();
    boolean add = form.getAddingLocation();

    /** We are just updating from the current form values.
     */
    if (!form.validateNewLocation()) {
      return "retry";
    }

    /* if a location with the same name, phone, e-mail, link, and creator exist
       in locations table then retrieve its locationid, otherwise add this
       location to the database and then retrieve its locationid.
     */

    LocationVO loc = form.getLocation();

    if (!add && (loc.getId() <= CalFacadeDefs.maxReservedLocationId)) {
      // claim it doesn't exist
      err.emit("org.ucal.calendar.pubevents.error.nosuchlocation",
               loc.getId());
      return "noSuchLocation";
    }

    if (add) {
      svci.ensureLocationExists(loc);
    } else {
      svci.replaceLocation(loc);
    }

    form.updatePrefs(null, null, loc);

    if (add) {
      msg.emit("org.ucal.calendar.pubevents.message.location.added");
    } else {
      msg.emit("org.ucal.calendar.pubevents.message.location.updated");
    }

    return "continue";
  }
}

