package edu.washington.cac.calfacade.shared;

import java.io.Serializable;

/** This class provides information about an event for a specific user and
 * session. There is no reference to the event, this information will be
 * obtained via a direct call and possibly associated with the event in some
 * containing structure.
 *
 * <p>This is designed to avoid extra references to event objects causing
 * problems wih persistace engines.
 *
 * @author Mike Douglass       douglm@rpi.edu
 */
public class EventInfo implements Serializable {
  protected boolean editable;

  protected boolean fromRef;

  protected boolean fromSubscription;

  /** Return true if this event is editable by the current user
   */
  public boolean getEditable() throws CalFacadeException {
    return editable;
  }

  /** Return true if this event is included as a reference in the current
   * non-public calendar
   */
  public boolean getFromRef() throws CalFacadeException {
    return fromRef;
  }

  /** Return true if this event is included as a subscription in the current
   * non-public calendar
   */
  public boolean getFromSubscription() throws CalFacadeException {
    return fromSubscription;
  }
}
