/* **********************************************************************
    Copyright 2005 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.uwcal.caldav;

import edu.rpi.cct.uwcal.calsvci.CalSvcI;
import edu.rpi.cct.uwcal.icalendar.IcalTranslator;
import edu.rpi.cct.webdav.servlet.shared.WebdavIntfException;
import edu.washington.cac.calfacade.shared.CalendarVO;

import java.util.Collection;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.Vector;

/** Class to represent a user in caldav.
 *
 *   @author Mike Douglass   douglm@rpi.edu
 */
public class CaldavUserNode extends CaldavUWCalNode {
  public CaldavUserNode(CaldavURI cdURI, CalSvcI svci,
                        IcalTranslator trans, boolean debug) {
    super(cdURI, svci, trans, debug);

    this.name = cdURI.getUserName();
    collection = true;
    allowsGet = false;

    if (!uri.endsWith("/")) {
      uri += "/";
    }

    contentLang = "en";
    contentLen = 0;
  }

  /** Return a collection of children objects. These will all be the names of
   * calendars.
   *
   * <p>For a user node all children will be calendars.
   */
  public Collection getChildren() throws WebdavIntfException {
    try {
      Collection cals = svci.getCalendars();
      Vector v = new Vector();

      /* Add the default calendar name first.
       */
      v.addElement(cdURI.getDefaultCalendarName());

      if (cals == null) {
        return v;
      }

      Iterator it = cals.iterator();

      while (it.hasNext()) {
        CalendarVO cal = (CalendarVO)it.next();

        v.addElement(cal.getName());
      }

      return v;
    } catch (Throwable t) {
      throw new WebdavIntfException(t);
    }
  }

  /* ====================================================================
   *                   Abstract methods
   * ==================================================================== */

  /** Return all properties special to this namespace for this node.
   * For example, if there is a creator property there will be a
   * WebdavProperty object for the property
   */
  public Enumeration properties() {
    return null;
  }

  /* ====================================================================
   *                   Private methods
   * ==================================================================== */
}
