/* **********************************************************************
    Copyright 2005 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.uwcal.caldav.filter;

import java.util.Iterator;
import java.util.Vector;

import org.apache.log4j.Logger;

/** Class to represent a calendar-query comp-filter
 *
 *   @author Mike Douglass   douglm@rpi.edu
 */
public class CompFilter {
  /* Name of component VEVENT etc */
  private String name;

  private boolean isDefined;

  private TimeRange timeRange;

  private Vector compFilters;

  private Vector propFilters;

  public CompFilter(String name) {
    this.name = name;
  }

  public void setName(String val) {
    name = val;
  }

  public String getName() {
    return name;
  }

  public void setIsDefined(boolean val) {
    isDefined = val;
  }

  public boolean getIsDefined() {
    return isDefined;
  }

  public void setTimeRange(TimeRange val) {
    timeRange = val;
  }

  public TimeRange getTimeRange() {
    return timeRange;
  }

  public Vector getCompFilters() {
    if (compFilters == null) {
      compFilters = new Vector();
    }

    return compFilters;
  }

  public void addCompFilter(CompFilter cf) {
    getCompFilters().add(cf);
  }

  public Vector getPropFilters() {
    if (propFilters == null) {
      propFilters = new Vector();
    }

    return propFilters;
  }

  public void addPropFilter(PropFilter pf) {
    getPropFilters().add(pf);
  }

  public void dump(Logger log, String indent) {
    StringBuffer sb = new StringBuffer(indent);

    sb.append("<comp-filter name=\"");
    sb.append(name);
    sb.append("\">");
    log.debug(sb.toString());

    if (isDefined) {
      log.debug(indent + "  " + "<is-defined/>");
    } else if (timeRange != null) {
      timeRange.dump(log, indent + "  ");
    }

    if (compFilters != null) {
      Iterator it = compFilters.iterator();

      while (it.hasNext()) {
        CompFilter cf = (CompFilter)it.next();
        cf.dump(log, indent + "  ");
      }
    }

    if (propFilters != null) {
      Iterator it = propFilters.iterator();

      while (it.hasNext()) {
        PropFilter pf = (PropFilter)it.next();
        pf.dump(log, indent + "  ");
      }
    }

    log.debug(indent + "<comp-filter/>");
  }
}

