/* **********************************************************************
    Copyright 2005 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.rpi.cct.webdav.servlet.common;

import edu.rpi.cct.webdav.servlet.shared.WebdavException;
import edu.rpi.cct.webdav.servlet.shared.WebdavNsNode;

import java.util.Iterator;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/** Class called to handle OPTIONS. We should determine what the current
 * url refers to and send a response which shows the allowable methods on that
 * resource.
 *
 *   @author Mike Douglass   douglm@rpi.edu
 */
public class OptionsMethod extends MethodBase {
  /** Called at each request
   */
  public void init() {
  }

  public void doMethod(HttpServletRequest req,
                        HttpServletResponse resp) throws WebdavException {
    if (debug) {
      trace("GetMethod: doMethod");
    }

    try {
      WebdavNsNode node = getNsIntf().getNode(getResourceUri(req));

      /* Apparently if the node doesn't exist we're supposed to respond
       * not found, rather than indicate if PUT is allowed for example.
       */
      if ((node == null) || !node.getExists()) {
        resp.setStatus(HttpServletResponse.SC_NOT_FOUND);
        return;
      }

      if (getNsIntf().getAccessControl()) {
        resp.addHeader("DAV", "1, 2, access-control");
      } else {
        resp.addHeader("DAV", "1, 2");
      }

      // Lisa say's we need this
      resp.addHeader("MS-Author-Via", "DAV");

      // This probably needs changes

      StringBuffer methods = new StringBuffer();
      Iterator mnames = getNsIntf().getServlet().getMethodNames().iterator();
      while (mnames.hasNext()) {
        if (methods.length() > 0) {
          methods.append(", ");
        }

        methods.append(mnames.next());
      }

      resp.addHeader("Allow", methods.toString());
    } catch (WebdavException we) {
      throw we;
    } catch (Throwable t) {
      throw new WebdavException(t);
    }
  }
}

