#
# MySQL initialization data for UWCalendar Quickstart
#
# @author Mike Douglass, Arlen Johnson, Greg Barnes, Cameron Mallory
# Bugfix by Jake Dolan
#
# This file contains insert statements
# Table create commands can be found in mysql.sql
#
#	To load use something similar to:
#	mysql -u userName -p  dbName < mysqlInit.sql
#
#	Be sure that dbName above matches the line below
#	that starts with USE
#
# Have received a report that insert statements into keyword_attrs
# table below do not work (mysql 4.1.10 on windows) due to auto_increment
# field 'kaid' not being listed in the fields list.  This seems
# to contradict the mysql documentation, so will leave as is for now.
# If you notice the same problem, please report it.
# 	--- Greg Barnes, June 24 2005

USE calendardb;

# ----------------------------- users -------------------------------------
insert into users (userid, username) values (2, '007-ts');
insert into users (userid, username) values (3, '1user');
insert into users (userid, username) values (4, 'caladmin');
insert into users (userid, username) values (5, 'calcontent');
insert into users (userid, username) values (6, 'calowner');
insert into users (userid, username) values (7, 'calowner2');
insert into users (userid, username) values (8, 'calowner3');
insert into users (userid, username) values (9, 'caluser1');
insert into users (userid, username) values (10, 'agrp_grp1');
insert into users (userid, username) values (11, 'agrp_grp2');
insert into users (userid, username) values (12, '007');
insert into users (userid, username) values (13, '007main');
insert into users (userid, username) values (14, '007unofficial');
insert into users (userid, username) values (15, '007other');

# --------------------------- locations -----------------------------------

insert into locations (locationid, address, creator, publicf)
  values (1, 'none','007', 'T');

insert into locations (locationid, address, creator, publicf)
  values (2, 'unknown', '007', 'T');

insert into locations (locationid, address, subaddress, creator, publicf)
  values (3, 'deleted', 'Used as a replacement when the owner of a public location used by others deletes the location', '007', 'T');

# --------------------------- sponsors ------------------------------------

insert into sponsors (sponsorid, name, creator, publicf)
  values (1, 'none', '007', 'T');

insert into sponsors (sponsorid, name, creator, publicf)
  values (2, 'unknown', '007', 'T');

insert into sponsors (sponsorid, name, phone, creator, publicf)
  values (3, 'deleted', 'Used as a replacement when the owner of a public sponsor used by others deletes the sponsor', '007', 'T');

# sponsors for the 'all calendars' page
insert into sponsors (sponsorid, name, creator, publicf)
  values (1667, 'Benefits Office', '007', 'T');

insert into sponsors (sponsorid, name, creator, publicf)
  values (1673, 'Recruiting and Candidate Services', '007', 'T');

insert into sponsors (sponsorid, name, creator, publicf)
  values (1672, 'Training and Development', '007', 'T');

insert into sponsors (sponsorid, name, creator, publicf)
  values (1668, 'Work/Life Office', '007', 'T');

# ------------- default keywords for official public events ---------------

insert into keywords (keywordid, word, creator, publicf)
  values (35, 'Academic Calendar', '007other', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (34, 'Holidays', '007other', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (33, 'Alerts', '007other', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (1, 'Benefits', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (2, 'Commencement', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (3, 'Concerts', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (24, 'Conferences', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (4, 'Dance', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (22, 'Deadlines', '007unofficial', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (5, 'Drama', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (6, 'Exhibits', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (7, 'Films', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (25, 'Forums', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (8, 'Health Sciences', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (9, 'Hearings', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (10, 'Lectures', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (29, 'Meetings', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (11, 'Open Houses', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (12, 'Operas', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (13, 'Radio', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (14, 'Readings', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (15, 'Sales', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (16, 'Seminars', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (17, 'Special Events', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (18, 'Sports', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (19, 'Television', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (20, 'Tours', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (21, 'Training', '007main', 'T');

insert into keywords (keywordid, word, creator, publicf)
  values (26, 'Workshops', '007main', 'T');

# ----------------------- authorised users --------------------------------

insert into auth (userid, usertype, lastname)
    values (3, 'A', 'dummy user to get things started');

insert into auth (userid, usertype, lastname)
    values (4, 'A', 'dummy admin user');

insert into auth (userid, usertype, lastname)
    values (5, 'C', 'dummy calendar content admin user');

insert into auth (userid, usertype, lastname)
    values (6, 'P', 'dummy public events owner user');

insert into auth (userid, usertype, lastname)
    values (7, 'P', 'dummy public events owner user');

insert into auth (userid, usertype, lastname)
    values (8, 'P', 'dummy public events owner user');

# ------------------------- admin groups ----------------------------------

insert into adminGroups values ('grp1', 'Demo group with 2 members',
                                'caladmin', 'agrp_grp1');

insert into adminGroups values ('grp2', 'Demo group with 2 members',
                                'calowner3', 'agrp_grp2');

insert into adminGroupMembers values ('grp1', 'caladmin');
insert into adminGroupMembers values ('grp1', 'calowner');
insert into adminGroupMembers values ('grp2', 'calowner2');
insert into adminGroupMembers values ('grp2', 'calowner3');

# ------------------------- lastmods ----------------------------------

insert into lastmods values ('pubevents', '2003-07-03 13:12:29.0');

# ----------------- tokens, props, params, alarms-----------------------

insert into tokens (token) values ('SPEAKER');
insert into tokens (token) values ('SPEAKER-AFFILIATION');

# ----------------- keyword attributes -----------------------

insert into keyword_attrs (kakeywordid, kaname, kaval) values (33, 'calcategoryclass', 'calalerts');
insert into keyword_attrs (kakeywordid, kaname, kaval) values (34, 'calcategoryclass', 'calHolidays');
insert into keyword_attrs (kakeywordid, kaname, kaval) values (35, 'calcategoryclass', 'calAcademicCalendar');
