//java

package edu.washington.cac.calfacade.shared;

import java.sql.Date;
import java.sql.Time;
import java.util.Calendar;

import junit.framework.TestCase;

/**
   Test the CheckData class
   @author Leman Chung
   @version 1.1
  */
public class CheckDataTest extends TestCase
{
   public CheckDataTest(String name)
   {
     super(name);
   }

   /**
     Get a Date for today
     @return today, as a <code>Date</code>
    */
   public Date today() {
     return new Date(Calendar.getInstance().getTime().getTime());
   }

   /**
     Get a Date for tomorrow
     @return tomorrow, as a <code>Date</code>
    */
   public Date tomorrow() {
     Calendar c = Calendar.getInstance();
     c.add(Calendar.DATE, 1);
     return new Date(c.getTime().getTime());
   }

   /**
     Get noon, as a time
     @return noon, as a <code>Time</code>
    */
   public Time noon() {
     Calendar c = Calendar.getInstance();
     c.clear();
     c.set(Calendar.HOUR_OF_DAY, 12);
     return new Time(c.getTime().getTime());
   }

   /**
     Get 6:30pm, as a time
     @return 6:30pm, as a <code>Time</code>
    */
   public Time sixThirtyPm() {
     Calendar c = Calendar.getInstance();
     c.clear();
     c.set(Calendar.HOUR_OF_DAY, 18);
     c.set(Calendar.MINUTE, 30);
     return new Time(c.getTime().getTime());
   }

   /**
     Test the checkDateTimes method
    */
   public void testCheckDateTimes()
   {
     // Test calls with no time
     assertTrue(CheckData.checkDateTimes(today(), null, today(), null,
                                         new StringBuffer()));
     assertTrue(CheckData.checkDateTimes(today(), null, tomorrow(), null,
                                         new StringBuffer()));
     assertFalse(CheckData.checkDateTimes(tomorrow(), null, today(), null,
                                          new StringBuffer()));

     // Test call with endtime, but no starttime
     assertFalse(CheckData.checkDateTimes(today(), null, today(), noon(),
                                         new StringBuffer()));

     // Test calls with starttime, but no endtime
     assertTrue(CheckData.checkDateTimes(today(), noon(), today(), null,
                                         new StringBuffer()));
     assertTrue(CheckData.checkDateTimes(today(), noon(), tomorrow(), null,
                                         new StringBuffer()));
     assertFalse(CheckData.checkDateTimes(tomorrow(), noon(), today(), null,
                                          new StringBuffer()));

     // Test calls with both times
     assertTrue(CheckData.checkDateTimes(today(), noon(), today(), noon(),
                                         new StringBuffer()));
     assertTrue(CheckData.checkDateTimes(today(), noon(), 
                                         today(), sixThirtyPm(),
                                         new StringBuffer()));
     assertTrue(CheckData.checkDateTimes(today(), noon(), tomorrow(), noon(),
                                         new StringBuffer()));
     assertTrue(CheckData.checkDateTimes(today(), noon(), 
                                          tomorrow(), sixThirtyPm(),
                                          new StringBuffer()));
     assertFalse(CheckData.checkDateTimes(today(), sixThirtyPm(), 
                                          today(), noon(),
                                          new StringBuffer()));
     assertFalse(CheckData.checkDateTimes(tomorrow(), noon(), today(), noon(),
                                          new StringBuffer()));
     assertFalse(CheckData.checkDateTimes(tomorrow(), sixThirtyPm(), 
                                          today(), noon(),
                                          new StringBuffer()));
     assertFalse(CheckData.checkDateTimes(tomorrow(), noon(), 
                                          today(), sixThirtyPm(),
                                          new StringBuffer()));
   }
}
